@@ -1,17 +1,12 @@
-import traceback
-
-import click
-from click._compat import get_text_stderr
-
-from pdm.context import context
+from pdm.iostream import stream
 
 
-class PdmException(click.ClickException):
-    def show(self, file=None):
-        if file is None:
-            file = get_text_stderr()
-        context.io.echo("Error: %s" % (self.format_message(),), file=file)
-        context.io.echo(traceback.format_exc(), verbosity=context.io.DETAIL, file=file)
+class PdmException(Exception):
+    pass
+
+
+class PdmUsageError(PdmException):
+    pass
 
 
 class RequirementError(PdmException, ValueError):
@@ -34,7 +29,7 @@ class CandidateInfoNotFound(PdmException):
     def __init__(self, candidate):
         message = (
             "No metadata information is available for "
-            f"{context.io.green(str(candidate))}."
+            f"{stream.green(str(candidate))}."
         )
         self.candidate = candidate
         super().__init__(message)
@@ -77,9 +72,7 @@ class ResolutionTooDeep(ResolutionError):
 class NoVersionsAvailable(ResolutionError):
     def __init__(self, requirement, parent):
         super().__init__(
-            "No version available for {}.".format(
-                context.io.green(requirement.as_line())
-            )
+            "No version available for {}.".format(stream.green(requirement.as_line()))
         )
         self.requirement = requirement
         self.parent = parent
